@@ -8,6 +8,7 @@ import unittest
 
 import fiona
 from fiona.collection import supported_drivers
+from fiona.errors import FionaValueError, DriverError, SchemaError, CRSError
 
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 
@@ -163,7 +164,8 @@ class UnsupportedDriverTest(unittest.TestCase):
             'geometry': 'Point', 
             'properties': {'label': 'str', u'verit\xe9': 'int'} }
         self.assertRaises(
-            ValueError, fiona.open, "/tmp/foo", "w", "FileGDB", schema=schema )
+            DriverError, 
+            fiona.open, "/tmp/foo", "w", "FileGDB", schema=schema)
 
 # The file writing tests below presume we can write to /tmp.
 
@@ -280,15 +282,15 @@ class LineWritingTest(unittest.TestCase):
         self.failUnlessEqual(self.sink.bounds, (0.0, -0.2, 0.0, 0.2))
 
 class PointAppendTest(unittest.TestCase):
-
+    # Tests 3D shapefiles too
     def setUp(self):
         os.mkdir("test_append_point")
         with fiona.open("docs/data/test_uk.shp", "r") as input:
-            schema = input.schema.copy()
-            schema['geometry'] = 'Point'
+            output_schema = input.schema.copy()
+            output_schema['geometry'] = '3D Point'
             with fiona.open(
                     "test_append_point/" + "test_append_point.shp", 
-                    "w", "ESRI Shapefile", schema
+                    "w", crs=None, driver="ESRI Shapefile", schema=output_schema
                     ) as output:
                 for f in input.filter(bbox=(-5.0, 55.0, 0.0, 60.0)):
                     f['geometry'] = {
@@ -301,7 +303,7 @@ class PointAppendTest(unittest.TestCase):
 
     def test_append_point(self):
         with fiona.open("test_append_point/test_append_point.shp", "a") as c:
-            self.assertEqual(c.schema['geometry'], 'Point')
+            self.assertEqual(c.schema['geometry'], '3D Point')
             c.write({'geometry': {'type': 'Point', 'coordinates': (0.0, 45.0)},
                      'properties': { 'FIPS_CNTRY': 'UK', 
                                      'AREA': 0.0, 
@@ -370,14 +372,15 @@ class CollectionTest(unittest.TestCase):
         self.assertRaises(ValueError, fiona.open, "/tmp/bogus.shp", "r+")
 
     def test_w_args(self):
-        self.assertRaises(ValueError, fiona.open, "test-no-iter.shp", "w")
-        self.assertRaises(ValueError, fiona.open, "test-no-iter.shp", "w", "Driver")
+        self.assertRaises(FionaValueError, fiona.open, "test-no-iter.shp", "w")
+        self.assertRaises(
+            FionaValueError, fiona.open, "test-no-iter.shp", "w", "Driver")
 
     def test_no_path(self):
-        self.assertRaises(OSError, fiona.open, "no-path.shp", "a")
+        self.assertRaises(IOError, fiona.open, "no-path.shp", "a")
 
     def test_no_read_conn_str(self):
-        self.assertRaises(OSError, fiona.open, "PG:dbname=databasename", "r")
+        self.assertRaises(IOError, fiona.open, "PG:dbname=databasename", "r")
 
     def test_no_read_directory(self):
         self.assertRaises(ValueError, fiona.open, ".", "r")
